# tensorstore-stubs
## What is it ?
Unofficial type stubs for tensorstore, following the convention of providing stubs in a separate package, as specified in PEP 561.
The stubs cover the most typical use cases of tensorstore.
Generally, these stubs are more limited than what tensorstore allows, but they adhere to best practices for utilizing the library.


